==> com_clubmanagement_1.1.zip: admin/views/about/tmpl/default.php <==
<?php defined('_JEXEC') or die('Restricted access'); ?>
<h1>About the component</h1>
<p>Clubmanagement should help you to manage your club using your joomla site.</p>
<p>I would consider it as in beta state. There is some work to do, but for most purposes, it will fit.</p>

<p>It was influenced by <a href="http://www.joomleague.de/">joomleague</a>. But where joomleague addresses more of a general overview of a league, clubmanagement goes for the adminstration of <strong>your</strong> club.</p>
<p>Clubmanagement is freeware and opensource. Feel free to modify. I don't have a bugtracker yet, so please report bugs by email.</p>

<h1>3<sup>rd</sup> party software</h1>
<h2>Icon sets</h2>
<ul>
	<li><a href="http://www.famfamfam.com">famfamfam silk icons</a></li>
	<li><a href="http://tango.freedesktop.org/Tango_Icon_Gallery">Tango Icon Gallery</a></li>
</ul>

<h2>Connection to event calendars</h2>
<p>Clubmanagement could be connected to some joomla event calenders to use as tournaments.</p>
<ul>
	<li><a href="http://www.schlu.net">eventlist</a></li>
</ul>

<h2>Javascript libraries</h2>
<p>Clubmanagement wouldn't be possible without the use of various js libraries. Thanks for making and maintaining them.</p>
<ul>
	<li>jQuery
		<ul>
			<li>dataTables-1.7</li>
			<li>jquery.ui.datepicker</li>
			<li>jqgrid</li>
			<li>jqueryui</li>
		</ul>
	</li>
</ul>

<h2>more libraries</h2>
<ul>
	<li>All charts are drawn using <a href="http://groups.google.com/group/mtchart">mtchart</a></li>
</ul>


<h1>Todo</h1>
<ul>
	<li>check user rights</li>
	<li>clean up code</li>
	<li>check sorting of members</li>
	<li>Frontend pages are ugly and unformatted</li>
	<li>Connect members to joomleague staff/players</li>
	<li>Translations</li>
</ul>

<h1>Translators</h1>
<p>none yet</p>

<h1>Known bugs</h1>
<p>nothing yet</p>

<h1>Changelog</h1>
<ul>
	<li>2010-12-16 - Version 1.0
		<p>initial release of clubmanagement</p>
	</li>
</ul>

<h1>About the author</h1>
<ul>
	<li>born in 1980, lives in Germany</li>
	<li>works as a system administrator and developer of websites</li>
	<li>has fun in finding simple and elegant solutions to everyday problems</li>
	<li><a href="mailto:joomla@familie-drobny.de">contact me</a>, I'll try to answer and help</li>
</ul>

==> com_clubmanagement_1.3.zip: admin/views/about/tmpl/default.php <==
<?php defined('_JEXEC') or die('Restricted access'); ?>
<h1>About the component</h1>
<img style="display: block; float: left;" src="<?php echo JURI::root(TRUE);?>/administrator/components/com_clubmanagement/assets/icons/clubmanagement-128.png" alt="clubmanagement icon" title="clubmanagement icon"/>
<p>Clubmanagement should help you to manage your club using your joomla site.</p>
<p>I would consider it as in beta state. There is some work to do, but for most purposes, it will fit.</p>

<p>It was influenced by <a href="http://www.joomleague.de/">joomleague</a>. But where joomleague addresses more of a general overview of a league, clubmanagement goes for the adminstration of <strong>your</strong> club.</p>
<p>Clubmanagement is freeware and opensource. Feel free to modify. I don't have a bugtracker yet, so please report bugs by email.</p>

<h1 style="clear: both;">3<sup>rd</sup> party software</h1>
<h2>Icon sets</h2>
<ul>
	<li><a href="http://www.famfamfam.com">famfamfam silk icons</a></li>
	<li><a href="http://tango.freedesktop.org/Tango_Icon_Gallery">Tango Icon Gallery</a></li>
</ul>

<h2>Connection to event calendars</h2>
<p>Clubmanagement could be connected to some joomla event calenders to use as tournaments.</p>
<ul>
	<li><a href="http://www.schlu.net">eventlist</a></li>
</ul>

<h2>Javascript libraries</h2>
<p>Clubmanagement wouldn't be possible without the use of various js libraries. Thanks for making and maintaining them.</p>
<ul>
	<li>jQuery
		<ul>
			<li>dataTables-1.7</li>
			<li>jquery.ui.datepicker</li>
			<li>jqgrid</li>
			<li>jqueryui</li>
		</ul>
	</li>
</ul>

<h2>more libraries</h2>
<ul>
	<li>All charts are drawn using <a href="http://groups.google.com/group/mtchart">mtchart</a></li>
</ul>


<h1>Todo</h1>
<ul>
	<li>check user rights</li>
	<li>clean up code</li>
	<li>check sorting of member</li>
	<li>Frontend pages are ugly and unformatted</li>
	<li>Connect member to joomleague staff/players</li>
	<li>Translations</li>
</ul>

<h1>Translators</h1>
<p>none yet</p>

<h1>Known bugs</h1>
<p>nothing yet</p>

<h1>Changelog</h1>
<ul>
	<li>2010-12-16 - Version 1.0
		<p>initial release of clubmanagement</p>
	</li>
</ul>

<h1>About the author</h1>
<ul>
	<li>born in 1980, lives in Germany</li>
	<li>works as a system administrator and developer of websites</li>
	<li>has fun in finding simple and elegant solutions to everyday problems</li>
	<li><a href="mailto:joomla@familie-drobny.de">contact me</a>, I'll try to answer and help</li>
</ul>
